def print_lol(the_list):
    """This function takes a positional argument called “the_list",
    which is any Python list (of, possibly, nested lists). Each data
    item in the provided list is (recursively) printed
    to the screen on its own line."""

    for each_item in the_list :
        if isinstance(each_item,list):
            print_lol(each_item)
        else :
            print(each_item)



from distutils.core import setup

setup(
    name = 'jitu1',
    version = '1.0.0',
    py_modules = ['jitu1'],
    author = 'jiten',
    author_email = 'jitenbnsl@gmail.com',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )
